'use strict';

var testLogger = require('../test-logger.js');
var config = require('../../config.js');

/**
 * Creates a test fixture for capturing AlgoKit logs.
 *
 * @example
 * ```typescript
 * const logs = algoKitLogCaptureFixture()
 *
 * beforeEach(logs.beforeEach)
 * afterEach(logs.afterEach)
 *
 * test('My test', () => {
 *     const capturedLogs = logs.testLogger.capturedLogs
 * })
 * ```
 *
 * @returns The fixture
 */
const algoKitLogCaptureFixture = () => {
    const originalLogger = config.Config.logger;
    let hybridLogger;
    return {
        get testLogger() {
            return hybridLogger;
        },
        beforeEach: () => {
            hybridLogger = new testLogger.TestLogger(originalLogger);
            config.Config.configure({
                logger: hybridLogger,
            });
        },
        afterEach: () => {
            config.Config.configure({
                logger: originalLogger,
            });
        },
    };
};

exports.algoKitLogCaptureFixture = algoKitLogCaptureFixture;
//# sourceMappingURL=algokit-log-capture-fixture.js.map
